<?php
/**
 * class TimestampClientScript
*
* Extends CClientScript to include a timestamp in references to local files.
*
* This timestamp will avoid issues that arise when server files are updates while
* the navigator's cache still serves old files.
*
* The client cache will still work.
*
* @author Mario DE WEERD
* @licence MIT License
*/
class TimestampClientScript extends CClientScript {
    /**
     * (non-PHPdoc)
     * @see CClientScript::unifyScripts()
     */
    protected function unifyScripts() {
        parent::unifyScripts();
        $cssFiles=array();
        foreach($this->cssFiles as $url=>$media)
        {
            $cssFiles[$this->getTimedUrl($url)]=$media;
        }
        $this->cssFiles=$cssFiles;
        foreach(array(self::POS_HEAD,self::POS_BEGIN,self::POS_END,self::POS_READY) as $i) {
            if(isset($this->scriptFiles[$i])) {
                $scripts=array();
                foreach($this->scriptFiles[$i] as $key=>$url) {
                    $url=$this->getTimedUrl($url);
                    $scripts[$url]=$this->getTimedUrl($url);
                }
                $this->scriptFiles[$i]=$scripts;
            }
        }
    }

    /**
     *
     * @param string $url Url to extend with timestamp
     * @return string url with timestamp
     */
    public function getTimedUrl($url) {
        $baseUrl=Yii::app()->getRequest()->getBaseUrl() . '/';
        if(strpos($url, '//')!==0) {
            $basePath=Yii::getPathOfAlias('webroot');
            if(strpos($url, $baseUrl) === 0) {
                $relativeUrl=substr($url, strlen($baseUrl) - 1);
            } else {
                $relativeUrl='/'.$url;
            }
            $resourcePath=$basePath . str_replace('/', DIRECTORY_SEPARATOR,
                    $relativeUrl);
            if(file_exists($resourcePath)) {
                $timestamp='?'.filemtime($resourcePath);
                return $url . $timestamp;
            }
        }
        return $url;
    }
}

